[][src]Enum epd_waveshare::color::Color

pub enum Color {
    Black,
    White,
}

Only for the Black/White-Displays

Variants

Black

Black color

White

White color

Methods

impl Color[src]

pub fn get_bit_value(self) -> u8[src]

Get the color encoding of the color for one bit

pub fn get_byte_value(self) -> u8[src]

Gets a full byte of black or white pixels

pub fn inverse(self) -> Color[src]

Returns the inverse of the given color.

Black returns White and White returns Black