Module graphics

Module graphics 

Graphics Support for EPDs

Structs

Display
Display buffer used for drawing with embedded graphics This can be rendered on EPD using …
VarDisplay
Same as Display, except that its characteristics are defined at runtime. See display for documentation as everything is the same except that default is replaced by a new method.

Enums

DisplayRotation
Display rotation, only 90° increments supported
VarDisplayError
Error found during usage of VarDisplay