[][src]Trait epd_waveshare::prelude::WaveshareThreeColorDisplay

pub trait WaveshareThreeColorDisplay<SPI, CS, BUSY, DC, RST>: WaveshareDisplay<SPI, CS, BUSY, DC, RST> where
    SPI: Write<u8>,
    CS: OutputPin,
    BUSY: InputPin,
    DC: OutputPin,
    RST: OutputPin
{ fn update_color_frame(
        &mut self,
        spi: &mut SPI,
        black: &[u8],
        chromatic: &[u8]
    ) -> Result<(), SPI::Error>;
fn update_achromatic_frame(
        &mut self,
        spi: &mut SPI,
        black: &[u8]
    ) -> Result<(), SPI::Error>;
fn update_chromatic_frame(
        &mut self,
        spi: &mut SPI,
        chromatic: &[u8]
    ) -> Result<(), SPI::Error>; }

Functions to interact with three color panels

Required methods

fn update_color_frame(
    &mut self,
    spi: &mut SPI,
    black: &[u8],
    chromatic: &[u8]
) -> Result<(), SPI::Error>

Transmit data to the SRAM of the EPD

Updates both the black and the secondary color layers

fn update_achromatic_frame(
    &mut self,
    spi: &mut SPI,
    black: &[u8]
) -> Result<(), SPI::Error>

Update only the black/white data of the display.

This must be finished by calling update_chromatic_frame.

fn update_chromatic_frame(
    &mut self,
    spi: &mut SPI,
    chromatic: &[u8]
) -> Result<(), SPI::Error>

Update only the chromatic data of the display.

This should be preceded by a call to update_achromatic_frame. This data takes precedence over the black/white data.

Loading content...

Implementors

impl<SPI, CS, BUSY, DC, RST> WaveshareThreeColorDisplay<SPI, CS, BUSY, DC, RST> for EPD1in54b<SPI, CS, BUSY, DC, RST> where
    SPI: Write<u8>,
    CS: OutputPin,
    BUSY: InputPin,
    DC: OutputPin,
    RST: OutputPin
[src]

impl<SPI, CS, BUSY, DC, RST> WaveshareThreeColorDisplay<SPI, CS, BUSY, DC, RST> for EPD2in9bc<SPI, CS, BUSY, DC, RST> where
    SPI: Write<u8>,
    CS: OutputPin,
    BUSY: InputPin,
    DC: OutputPin,
    RST: OutputPin
[src]

fn update_achromatic_frame(
    &mut self,
    spi: &mut SPI,
    black: &[u8]
) -> Result<(), SPI::Error>
[src]

Update only the black/white data of the display.

Finish by calling update_chromatic_frame.

fn update_chromatic_frame(
    &mut self,
    spi: &mut SPI,
    chromatic: &[u8]
) -> Result<(), SPI::Error>
[src]

Update only chromatic data of the display.

This data takes precedence over the black/white data.

Loading content...